import { __extends, __rest, __assign } from './../external/tslib/tslib.es6.js';
import React from 'react';
import ReactDOM from 'react-dom';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './Drawer.module.scss.js';

var Drawer = function (_super) {
  __extends(Drawer, _super);

  function Drawer(props) {
    var _this = _super.call(this, props) || this;

    _this.determineBodyOverflowStyle = function () {
      // Set overflow hidden in order to prevent body scrolling while
      // the full modal is opened
      var _a = _this.props,
          disabledBodyScrolling = _a.disabledBodyScrolling,
          visible = _a.visible;

      if (disabledBodyScrolling) {
        window.document.body.style.overflowY = visible ? 'hidden' : 'unset';
      }
    };

    _this.handleKeyDown = function (event) {
      var _a = _this.props,
          onRequestToClose = _a.onRequestToClose,
          closeKey = _a.closeKey,
          preventToClose = _a.preventToClose;
      var closeKeyWasPressed = String(event.key) === String(closeKey);

      if (closeKeyWasPressed && !preventToClose) {
        onRequestToClose();
      }
    };

    _this.ref = /*#__PURE__*/React.createRef();
    return _this;
  }

  Drawer.prototype.componentDidMount = function () {
    // eslint-disable-next-line react/destructuring-assignment
    if (this.props.visible) {
      document.addEventListener('keydown', this.handleKeyDown);
    }

    this.determineBodyOverflowStyle();
  };

  Drawer.prototype.componentDidUpdate = function (prevProps) {
    var _a = this.props,
        visible = _a.visible,
        onOpen = _a.onOpen,
        onClose = _a.onClose;

    if (visible !== prevProps.visible) {
      // Prop callbacks
      if (visible) {
        onOpen();
      } else {
        onClose();
      }

      this.determineBodyOverflowStyle(); // Add / Remove event for closing using keyboard

      if (visible) document.addEventListener('keydown', this.handleKeyDown);else document.removeEventListener('keydown', this.handleKeyDown);
    }
  };

  Drawer.prototype.componentWillUnmount = function () {
    document.removeEventListener('keydown', this.handleKeyDown);
  };

  Object.defineProperty(Drawer.prototype, "sizeStyle", {
    get: function () {
      var _a = this.props,
          topOffset = _a.topOffset,
          leftOffset = _a.leftOffset;
      return {
        top: topOffset,
        left: leftOffset,
        width: "calc(100% - " + leftOffset + ")",
        height: "calc(100% - " + topOffset + ")"
      };
    },
    enumerable: false,
    configurable: true
  });

  Drawer.prototype.render = function () {
    var sizeStyle = this.sizeStyle;
    var _a = this.props,
        visible = _a.visible;
    _a.disabledBodyScrolling;
    _a.preventToClose;
    _a.closeKey;
    _a.topOffset;
    _a.leftOffset;
    var metadata = _a.metadata,
        className = _a.className,
        children = _a.children;
    _a.onOpen;
    _a.onClose;
    _a.onRequestToClose;

    var remainingProps = __rest(_a, ["visible", "disabledBodyScrolling", "preventToClose", "closeKey", "topOffset", "leftOffset", "metadata", "className", "children", "onOpen", "onClose", "onRequestToClose"]);

    var containerClassName = classnames(styles.drawerContainer, className);
    var Component = /*#__PURE__*/React.createElement("div", __assign({}, remainingProps, parseMetadata(metadata), {
      className: containerClassName,
      style: sizeStyle,
      "data-state": visible && 'show',
      ref: this.ref,
      role: "dialog",
      "aria-hidden": !visible,
      "aria-modal": visible || undefined
    }), children);
    return /*#__PURE__*/ReactDOM.createPortal(Component, window.document.body);
  }; // eslint-disable-next-line react/static-property-placement


  Drawer.defaultProps = {
    visible: false,
    disabledBodyScrolling: true,
    preventToClose: false,
    closeKey: 'Escape',
    topOffset: '0px',
    leftOffset: '280px',
    className: null,
    children: null,
    onOpen: function () {},
    onClose: function () {},
    onRequestToClose: function () {}
  };
  return Drawer;
}(React.PureComponent);

export { Drawer as default };
//# sourceMappingURL=Drawer.js.map
