import { __extends, __assign } from './../external/tslib/tslib.es6.js';
import React from 'react';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './DrawerHeader.module.scss.js';

var DrawerHeader = function (_super) {
  __extends(DrawerHeader, _super);

  function DrawerHeader() {
    var _this = _super !== null && _super.apply(this, arguments) || this;

    _this.handleRef = function (ref) {
      _this.ref = ref;

      _this.attachEvents();
    };

    _this.attachEvents = function () {
      var fixed = _this.props.fixed;

      if (_this.ref) {
        var parentEl = _this.ref.parentElement; // Make sure just to add the event if is the drawer element

        var drawerEl = parentEl && parentEl.getAttribute('role') === 'drawer' ? parentEl : null;

        if (!drawerEl) {
          return;
        }

        if (fixed) {
          drawerEl.addEventListener('scroll', _this.onScroll);
        } else {
          drawerEl.removeEventListener('scroll', _this.onScroll);
        }
      }
    };

    _this.onScroll = function (event) {
      var scrollTop = event.currentTarget.scrollTop;
      var appendFixedClass = scrollTop !== 0;

      _this.ref.classList[appendFixedClass ? 'add' : 'remove'](styles.drawerHeaderContainerFixedWithScroll);
    };

    return _this;
  }

  DrawerHeader.prototype.componentUpdate = function (prevProps) {
    var fixed = this.props.fixed;
    if (prevProps.fixed !== fixed) this.attachEvents();
  };

  DrawerHeader.prototype.render = function () {
    var _a;

    var _b = this.props,
        fixed = _b.fixed,
        className = _b.className,
        children = _b.children,
        metadata = _b.metadata;
    var containerClassName = classnames((_a = {}, _a[styles.drawerHeaderContainerFixed] = fixed, _a), styles.drawerHeaderContainer, className);
    return /*#__PURE__*/React.createElement("div", __assign({}, parseMetadata(metadata), {
      className: containerClassName,
      ref: this.handleRef
    }), children);
  }; // eslint-disable-next-line react/static-property-placement


  DrawerHeader.defaultProps = {
    fixed: false,
    className: null
  };
  return DrawerHeader;
}(React.PureComponent);

export { DrawerHeader as default };
//# sourceMappingURL=DrawerHeader.js.map
